docs.rs failed to build ic-bn-lib-0.3.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
ic-bn-lib-0.2.4
ic-bn-lib
Internet Computer Boundary Nodes shared modules.
Description
This is intended to be used with the HTTP services of the IC: ic-gateway and ic-boundary.
Modules planned:
- HTTP
- Client
- Server
- DNS resolver
- Caching
- Misc utils
- TLS
- ACME
- DNS
- ALPN
- Tickets
- Sessions
- ACME
Contributing
External code contributions are currently not being accepted to this repository.
License
This project is licensed under the Apache License, Version 2.0. See the LICENSE file for more details.