Crate ic_bn_lib

Crate ic_bn_lib 

Re-exports

pub use hickory_proto;
pub use hickory_resolver;
pub use hyper;
pub use hyper_util;
pub use ic_agent;
pub use ic_bn_lib_common;
pub use prometheus;
pub use reqwest;
pub use rustls;
pub use uuid;

Modules

http
network
pubsub
tasks
tests
tls
utils

Macros

dyn_event
email
Converts a string representation to an EmailAddress. Panics when an error occurs.
hname
hval
retry_async
Retrying async closures/functions holding mutable references is a pain in Rust. So, for now, we’ll have to use a macro to work that around.

Structs

SerializeOr

Enums

RetryError
Error to be used with retry_async macro which indicates whether it should be retried or not.

Traits

BoolYesNo
Converts bool to yes/no static str
IpFamily
Returns family of an IP address
SerializeOption

Functions

download_url
Downloads the given url and returns it as Bytes
download_url_async
Downloads the given url and returns it as Bytes
download_url_to
Downloads the given url to given path. Destination folder must exist.
download_url_to_async
Downloads the given url to given path. Destination folder must exist.
truncate
Truncates the given string to around n bytes, on the closest UTF-8 code point boundary.